@@ -1,5 +1,7 @@
+import cgi
 from functools import lru_cache
 import json
+import mimetypes
 from os import getcwd, path
 from typing import Any, Callable, Dict, IO
 from urllib.parse import urlparse
@@ -41,10 +43,26 @@ def _read_document_content(base_uri: str) -> Dict[str, Any]:
     if not url.scheme:
         prefix = "" if base_uri.startswith("/") else getcwd()
         base_uri = "file://" + path.join(prefix, base_uri)
-    if base_uri.endswith(".json"):
-        loader: Callable = json.load
-    else:
-        loader = CONTENT_LOADER
     with urlopen(base_uri) as conn:
+        loader = _get_loader(conn)
         content = loader(conn)
     return content
+
+
+def _get_loader(conn) -> Callable:
+    """Identify the best loader based on connection."""
+    content_type = _get_content_type(conn)
+    if "json" in content_type:
+        return json.load
+    return CONTENT_LOADER  # Fall back to default (yaml if installed)
+
+
+def _get_content_type(conn) -> str:
+    """Pull out mime type from a connection.
+
+    Prefer explicit header if available, otherwise guess from url.
+    """
+    content_type = mimetypes.guess_type(conn.url)[0] or ""
+    if hasattr(conn, "getheaders"):
+        content_type = dict(conn.getheaders()).get("Content-Type", content_type)
+    return cgi.parse_header(content_type)[0]
